@@ -19,6 +19,14 @@ class ExtendedTestCaseTestCase(ExtendedTestCase):
         cls.superuser = User(username="superuser", is_superuser=True)
         cls.superuser.save()
 
+    def test_assert_response_status_code(self):
+        response = self.client.get(self.url_access_all)
+        self.assertResponseStatusCode(response, 200)
+        with self.assertRaises(AssertionError):
+            self.assertResponseStatusCode(response, "200")
+        with self.assertRaises(AssertionError):
+            self.assertResponseStatusCode(response, [200, 201])
+
     def test_assert_response_ok(self):
         response = self.client.get(self.url_access_all)
         self.assertResponseOk(response)
@@ -30,6 +38,8 @@ class ExtendedTestCaseTestCase(ExtendedTestCase):
         self.assertLoginRequired(self.url_access_authenticated)
         with self.assertRaises(AssertionError):
             self.assertLoginRequired(self.url_access_all)
+        with self.assertRaises(AssertionError):
+            self.assertLoginRequired(reverse("redirect-root"))
 
     def test_assert_login_not_required(self):
         self.assertLoginNotRequired(reverse("home"))
@@ -46,11 +56,13 @@ class ExtendedTestCaseTestCase(ExtendedTestCase):
         self.assertAllowed(self.url_access_all, user=None)
         self.assertAllowed(self.url_access_all, user=self.user)
         self.assertAllowed(self.url_access_all, user=self.superuser)
+        self.assertAllowed(self.url_access_all, user=[None, self.user, self.superuser])
 
         self.assertAllowed(self.url_access_authenticated, user=self.user)
         self.assertAllowed(self.url_access_authenticated, user=self.superuser)
         with self.assertRaises(AssertionError):
             self.assertAllowed(self.url_access_authenticated, user=None)
+        self.assertAllowed(self.url_access_all, user=[self.user, self.superuser])
 
         self.assertAllowed(self.url_access_superuser, user=self.superuser)
         with self.assertRaises(AssertionError):
@@ -58,6 +70,10 @@ class ExtendedTestCaseTestCase(ExtendedTestCase):
         with self.assertRaises(AssertionError):
             self.assertAllowed(self.url_access_superuser, user=self.user)
 
+        self.assertAllowed(self.url_access_superuser, user=[self.superuser])
+        with self.assertRaises(AssertionError):
+            self.assertAllowed(self.url_access_superuser, user=[None, self.user, self.superuser])
+
     def test_assert_forbidden(self):
         with self.assertRaises(AssertionError):
             self.assertForbidden(self.url_access_all, user=None)
@@ -85,6 +101,8 @@ class ExtendedTestCaseTestCase(ExtendedTestCase):
         self.assertNotFound(self.url_does_not_exist, user=None)
         self.assertNotFound(self.url_does_not_exist, user=self.user)
         self.assertNotFound(self.url_does_not_exist, user=self.superuser)
+        self.assertNotFound(self.url_does_not_exist, user=[None, self.user, self.superuser])
+
         with self.assertRaises(AssertionError):
             self.assertNotFound(self.url_access_all, user=None)
         with self.assertRaises(AssertionError):
